\name{ME_Entity_Annotator}
\alias{ME_Entity_Annotator}
\title{Apache OpenNLP based entity annotators}
\description{
  Generate an annotator which computes entity annotations using the
  Apache OpenNLP Maxent name finder.
}
\usage{
ME_Entity_Annotator(language = "en", kind = "person", probs = FALSE,
                    model = NULL)
}
\arguments{
  \item{language}{
    a character string giving the ISO-639 code of the language being
    processed by the annotator.
  }
  \item{kind}{
    a character string giving the \sQuote{kind} of entity to be
    annotated (person, date, \dots).
  }
  \item{probs}{
    a logical indicating whether the computed annotations should provide
    the token probabilities obtained from the Maxent model as their
    \sQuote{prob} feature.
  }
  \item{model}{
    a character string giving the path to the Maxent model file to be
    used, or \code{NULL} indicating to use a default model file for the
    given language (if available, see \bold{Details}).
  }
}
\value{
  An \code{\link[NLP]{Annotator}} object giving the created entity
  annotator.
}
\details{
  See \url{http://opennlp.sourceforge.net/models-1.5/} for available
  model files.  These can conveniently be made available to \R by
  installing the respective \pkg{openNLPmodels.\var{language}} package
  from the repository at \url{http://datacube.wu.ac.at}.
}
\seealso{
  \url{http://opennlp.apache.org} for more information about Apache
  OpenNLP.
}
\examples{
\donttest{
## Requires package 'openNLPmodels.en' from the repository at
## <http://datacube.wu.ac.at>.

require("NLP")
## Some text.
s <- paste(c("Pierre Vinken, 61 years old, will join the board as a ",
             "nonexecutive director Nov. 29.\n",
             "Mr. Vinken is chairman of Elsevier N.V., ",
             "the Dutch publishing group."),
           collapse = "")
s <- as.String(s)

## Need sentence and word token annotations.
sent_token_annotator <- ME_Sent_Token_Annotator()
word_token_annotator <- ME_Word_Token_Annotator()
a2 <- annotate(s, list(sent_token_annotator, word_token_annotator))

## Entity recognition for persons.
entity_annotator <- ME_Entity_Annotator()
entity_annotator
annotate(s, entity_annotator, a2)
## Directly:
entity_annotator(s, a2)
## And slice ...
s[entity_annotator(s, a2)]
## Variant with sentence probabilities as features.
annotate(s, ME_Entity_Annotator(probs = TRUE), a2)
}
}
